@@ -12,13 +12,13 @@ import abc
 import json
 from nonebot import logger
 from pathlib import Path
-from typing import Union, Dict, Optional, List, Tuple
+from typing import Union, List, Tuple
 from dataclasses import dataclass
 from fuzzywuzzy import process, fuzz
 from PIL import Image
 from nonebot.plugin import PluginMetadata
 
-from .img_tool import simple_text, multi_text, calculate_text_size, ImageFactory, Box
+from .img_tool import simple_text, multi_text, calculate_text_size, ImageFactory, Box, auto_resize_text
 
 
 # 功能的数据信息
@@ -103,15 +103,21 @@ class Template(PicTemplate):
 
     def load_resource(self):
         cwd = Path.cwd()
-        with (cwd / 'menu_config'/ 'config.json').open('r', encoding='utf-8') as fp:
+        with (cwd / 'menu_config' / 'config.json').open('r', encoding='utf-8') as fp:
             config = json.loads(fp.read())
         self.using_font = config['default']
 
     def generate_main_menu(self, data) -> Image:
+        # 列数
         column_count = len(data) + 1
+        # 数据行数
         row_count = len(data[0])
-        # 数据尺寸测算
-        row_size_list = []
+        # 数据及表头尺寸测算
+        row_size_list = [tuple(
+                map(lambda _x: calculate_text_size(_x, self.basic_font_size, self.using_font),
+                    ('序号', '插件名', '插件描述'))
+        )]
+        # 计算id，插件名，插件描述的尺寸
         for x in range(row_count):
             index_size = calculate_text_size(str(x + 1), self.basic_font_size, self.using_font)
             plugin_name_size = calculate_text_size(data[0][x], self.basic_font_size, self.using_font)
@@ -121,21 +127,26 @@ class Template(PicTemplate):
                                                  box_size=(300, 0)
                                                  ).size
             row_size_list.append((index_size, plugin_name_size, plugin_description_size))
-        # 边距
+        # 单元格边距
         margin = 10
-        row_height_list = [max(map(lambda i: i[1], row_size_list[x])) + margin * 2 for x in range(row_count)]
+        # 确定每行的行高
+        row_height_list = [max(map(lambda i: i[1], row_size_list[x])) + margin * 2 for x in range(row_count + 1)]
+        # 确定每列的列宽
         col_max_width_tuple = (
             max((x[0][0] + margin * 2 for x in row_size_list)),
             max((x[1][0] + margin * 2 for x in row_size_list)),
             max((x[2][0] + margin * 2 for x in row_size_list))
         )
+        # 确定表格底版的长和宽
         table_width = sum(col_max_width_tuple) + 3
         table_height = sum(row_height_list) + 3
         table = ImageFactory(
             Image.new('RGBA', (table_width, table_height), self.colors['white'])
         )
+        # 绘制基点和移动锚点
         initial_point, basis_point = (1, 1), [1, 1]
-        for row_id in range(row_count):
+        # 为单元格添加box和绘制边框
+        for row_id in range(row_count + 1):
             for col_id in range(column_count):
                 box_size = (col_max_width_tuple[col_id], row_height_list[row_id])
                 table.add_box(f'box_{row_id}_{col_id}',
@@ -145,17 +156,26 @@ class Template(PicTemplate):
                 basis_point[0] += box_size[0]
             basis_point[0] = initial_point[0]
             basis_point[1] += row_height_list[row_id]
+        # 向单元格中填字
+        for i, text in enumerate(('序号', '插件名', '插件描述')):
+            header = simple_text(text, self.basic_font_size, self.using_font, self.colors['blue'])
+            table.img_paste(
+                header,
+                table.align_box(f'box_0_{i}', header, align='center'),
+                isalpha=True
+            )
         for x in range(row_count):
-            id_text = simple_text(str(x + 1), self.basic_font_size, self.using_font, self.colors['blue'])
+            row_id = x + 1
+            id_text = simple_text(str(row_id), self.basic_font_size, self.using_font, self.colors['blue'])
             table.img_paste(
                 id_text,
-                table.align_box(f'box_{x}_0', id_text, align='center'),
+                table.align_box(f'box_{row_id}_0', id_text, align='center'),
                 isalpha=True
             )
             plugin_name_text = simple_text(data[0][x], self.basic_font_size, self.using_font, self.colors['blue'])
             table.img_paste(
                 plugin_name_text,
-                table.align_box(f'box_{x}_1', plugin_name_text, align='center'),
+                table.align_box(f'box_{row_id}_1', plugin_name_text, align='center'),
                 isalpha=True
             )
             plugin_description_text = multi_text(data[1][x],
@@ -166,29 +186,56 @@ class Template(PicTemplate):
                                                  )
             table.img_paste(
                 plugin_description_text,
-                table.align_box(f'box_{x}_2', plugin_description_text, align='center'),
+                table.align_box(f'box_{x+1}_2', plugin_description_text, align='center'),
                 isalpha=True
             )
         table_size = table.img.size
+        # 添加注释
+        note_basic_text = simple_text('注：',
+                                      size=self.basic_font_size,
+                                      color=self.colors['blue'],
+                                      font=self.using_font)
+        note_text = multi_text('查询菜单的详细使用方法请发送\n[菜单 PicMenu]',
+                               box_size=(table_size[0] - 30 - note_basic_text.size[0] - 10, 0),
+                               default_font=self.using_font,
+                               default_color=self.colors['blue'],
+                               default_size=self.basic_font_size,
+                               spacing=4,
+                               horizontal_align="middle"
+                               )
+        note_img = ImageFactory(
+            Image.new('RGBA',
+                      (note_text.size[0] + 10 + note_basic_text.size[0],
+                       max((note_text.size[1], note_basic_text.size[1]))),
+                      self.colors['white'])
+        )
+        note_img.img_paste(note_basic_text, (0, 0), isalpha=True)
+        note_img.img_paste(note_text, (note_basic_text.size[0] + 10, 0), isalpha=True)
         main_menu = ImageFactory(
-            Image.new('RGBA', (table_size[0] + 140, table_size[1] + 190), color=self.colors['white'])
+            Image.new('RGBA',
+                      (table_size[0] + 140, table_size[1] + note_img.img.size[1] + 210),
+                      color=self.colors['white'])
+        )
+        main_menu.img_paste(
+            note_img.img,
+            main_menu.align_box('self', table.img, pos=(0, 140), align='horizontal')
         )
         main_menu.img_paste(
             table.img,
-            main_menu.align_box('self', table.img, pos=(0, 150), align='horizontal')
+            main_menu.align_box('self', table.img, pos=(0, 160 + note_img.img.size[1]), align='horizontal')
         )
         main_menu.add_box('border_box',
                           main_menu.align_box('self',
-                                              (table_size[0] + 40, table_size[1] + 70),
+                                              (table_size[0] + 40, table_size[1] + note_img.img.size[1] + 80),
                                               pos=(0, 100),
                                               align='horizontal'),
-                          (table_size[0] + 40, table_size[1] + 70))
+                          (table_size[0] + 40, table_size[1] + note_img.img.size[1] + 90))
         main_menu.rectangle('border_box', outline=self.colors['blue'], width=5)
         border_box_top_left = main_menu.boxes['border_box'].topLeft
         main_menu.rectangle(Box((border_box_top_left[0] - 25, border_box_top_left[1] - 25),
                                 (50, 50)), outline=self.colors['yellow'], width=5)
         main_menu.add_box('title_box', (0, 0), (main_menu.get_size()[0], 100))
-        title = simple_text('插件菜单', 60, self.using_font, self.colors['blue'])
+        title = auto_resize_text('插件菜单', 60, self.using_font, (table_width-60, 66), self.colors['blue'])
         main_menu.img_paste(title, main_menu.align_box('title_box', title, align='center'), isalpha=True)
         return main_menu.img
 
@@ -197,8 +244,13 @@ class Template(PicTemplate):
         data = plugin_data.funcs
         column_count = 5
         row_count = len(data)
-        # 数据尺寸测算
-        row_size_list = []
+        # 数据及表头尺寸测算
+        row_size_list = [tuple(
+            map(
+                lambda _x: calculate_text_size(_x, self.basic_font_size, self.using_font),
+                ('序号', '功能', '触发方式', '触发条件', '功能简述')
+            )
+        )]
         for index, func_data in enumerate(data):
             index_size = calculate_text_size(str(index + 1), self.basic_font_size, self.using_font)
             func_size = calculate_text_size(func_data.func, self.basic_font_size, self.using_font)
@@ -213,7 +265,7 @@ class Template(PicTemplate):
         # 边距
         margin = 10
         # 测行高
-        row_height_list = [max(map(lambda i: i[1], row_size_list[x])) + margin * 2 for x in range(row_count)]
+        row_height_list = [max(map(lambda i: i[1], row_size_list[x])) + margin * 2 for x in range(row_count+1)]
         col_max_width_tuple = (
             max((x[0][0] + margin * 2 for x in row_size_list)),
             max((x[1][0] + margin * 2 for x in row_size_list)),
@@ -229,7 +281,7 @@ class Template(PicTemplate):
         )
         initial_point, basis_point = (1, 1), [1, 1]
         # 建立基准box
-        for row_id in range(row_count):
+        for row_id in range(row_count + 1):
             for col_id in range(column_count):
                 box_size = (col_max_width_tuple[col_id], row_height_list[row_id])
                 table.add_box(f'box_{row_id}_{col_id}',
@@ -239,20 +291,29 @@ class Template(PicTemplate):
                 basis_point[0] += box_size[0]
             basis_point[0] = initial_point[0]
             basis_point[1] += row_height_list[row_id]
+        # 向单元格中填字
+        for i, text in enumerate(('序号', '功能', '触发方式', '触发条件', '功能简述')):
+            header = simple_text(text, self.basic_font_size, self.using_font, self.colors['blue'])
+            table.img_paste(
+                header,
+                table.align_box(f'box_0_{i}', header, align='center'),
+                isalpha=True
+            )
         # 填字
         for index, func_data in enumerate(data):
+            row_id = index + 1
             # 第一个cell填id
-            id_text = simple_text(str(index + 1), self.basic_font_size, self.using_font, self.colors['blue'])
+            id_text = simple_text(str(row_id), self.basic_font_size, self.using_font, self.colors['blue'])
             table.img_paste(
                 id_text,
-                table.align_box(f'box_{index}_0', id_text, align='center'),
+                table.align_box(f'box_{row_id}_0', id_text, align='center'),
                 isalpha=True
             )
             # 第二个cell里填func（功能）
             func_text = simple_text(func_data.func, self.basic_font_size, self.using_font, self.colors['blue'])
             table.img_paste(
                 func_text,
-                table.align_box(f'box_{index}_1', func_text, align='center'),
+                table.align_box(f'box_{row_id}_1', func_text, align='center'),
                 isalpha=True
             )
             # 第三个cell里填trigger_method（触发方式）
@@ -260,7 +321,7 @@ class Template(PicTemplate):
                                               self.colors['blue'])
             table.img_paste(
                 trigger_method_text,
-                table.align_box(f'box_{index}_2', trigger_method_text, align='center'),
+                table.align_box(f'box_{row_id}_2', trigger_method_text, align='center'),
                 isalpha=True
             )
             # 第四个cell里填trigger_condition（触发条件）
@@ -268,7 +329,7 @@ class Template(PicTemplate):
                                                  self.colors['blue'])
             table.img_paste(
                 trigger_condition_text,
-                table.align_box(f'box_{index}_3', trigger_condition_text, align='center'),
+                table.align_box(f'box_{row_id}_3', trigger_condition_text, align='center'),
                 isalpha=True
             )
             # 第五个cell里填brief_des（功能简述）
@@ -280,7 +341,7 @@ class Template(PicTemplate):
                                         )
             table.img_paste(
                 brief_des_text,
-                table.align_box(f'box_{index}_4', brief_des_text, align='center'),
+                table.align_box(f'box_{row_id}_4', brief_des_text, align='center'),
                 isalpha=True
             )
         # 获取table尺寸
@@ -290,7 +351,7 @@ class Template(PicTemplate):
                                        color=self.colors['blue'],
                                        font=self.using_font)
         usage_text = multi_text(plugin_data.usage,
-                                box_size=(table_size[0]-30-usage_basic_text.size[0]-10, 0),
+                                box_size=(table_size[0] - 30 - usage_basic_text.size[0] - 10, 0),
                                 default_font=self.using_font,
                                 default_color=self.colors['blue'],
                                 default_size=self.basic_font_size
@@ -298,7 +359,8 @@ class Template(PicTemplate):
         # 合成usage文字图片
         usage_img = ImageFactory(
             Image.new('RGBA',
-                      (usage_text.size[0] + 10 + usage_basic_text.size[0], max((usage_text.size[1], usage_basic_text.size[1]))),
+                      (usage_text.size[0] + 10 + usage_basic_text.size[0],
+                       max((usage_text.size[1], usage_basic_text.size[1]))),
                       self.colors['white'])
         )
         usage_img.img_paste(usage_basic_text, (0, 0), isalpha=True)
@@ -337,7 +399,7 @@ class Template(PicTemplate):
                                 (50, 50)), outline=self.colors['yellow'], width=5)
         main_menu.add_box('title_box', (0, 0), (main_menu.get_size()[0], 100))
         # 添加插件名title
-        title = simple_text(plugin_name, 60, self.using_font, self.colors['blue'])
+        title = auto_resize_text(plugin_name, 60, self.using_font, (table_width - 60, 66), self.colors['blue'])
         main_menu.img_paste(title, main_menu.align_box('title_box', title, align='center'), isalpha=True)
         return main_menu.img
 
@@ -347,14 +409,14 @@ class Template(PicTemplate):
                                        color=self.colors['blue'],
                                        font=self.using_font)
         usage_text = multi_text(plugin_data.usage,
-                                box_size=(600 , 0),
+                                box_size=(600, 0),
                                 default_font=self.using_font,
                                 default_color=self.colors['blue'],
                                 default_size=self.basic_font_size
                                 )
         # 合成usage文字图片
         usage_img = ImageFactory(
-            Image.new('RGBA', (usage_text.size[0]+10+usage_basic_text.size[0],
+            Image.new('RGBA', (usage_text.size[0] + 10 + usage_basic_text.size[0],
                                max((usage_text.size[1], usage_basic_text.size[1]))),
                       self.colors['white'])
         )
@@ -390,7 +452,12 @@ class Template(PicTemplate):
                                 (50, 50)), outline=self.colors['yellow'], width=5)
         main_menu.add_box('title_box', (0, 0), (main_menu.get_size()[0], 100))
         # 添加插件名title
-        title = simple_text(plugin_data.name, 60, self.using_font, self.colors['blue'])
+        title = auto_resize_text(plugin_data.name,
+                                 60,
+                                 self.using_font,
+                                 (usage_text_size[0] - 40, 66),
+                                 self.colors['blue']
+                                 )
         main_menu.img_paste(title, main_menu.align_box('title_box', title, align='center'), isalpha=True)
         return main_menu.img
 
@@ -497,7 +564,8 @@ class DataManager(object):
     def __init__(self):
         self.plugin_menu_data_list: List[PluginMenuData] = []  # 存放menu数据的列表
         self.plugin_names: List[str] = []  # 有menu_data的插件名列表
-        self.original_plugin_names: List[str] = []  # 无menu_data，但有meta_data的插件名列表
+        self.original_plugin_meta_names = []
+        self.original_plugin_names = []
 
     def load_plugin_info(self):
         # 取已经加载的插件信息
@@ -516,6 +584,7 @@ class DataManager(object):
                     menu_template = 'default'
             else:
                 self.original_plugin_names.append(plugin.name)
+                self.original_plugin_meta_names.append(meta_data.name)
                 logger.opt(colors=True).success(f'<y>{meta_data.name}</y> 菜单数据已加载')
                 continue
             # 数据整合
@@ -548,9 +617,8 @@ class DataManager(object):
             menu_data.description for menu_data in self.plugin_menu_data_list
         ]
         for plugin_name in self.original_plugin_names:
-            print(plugin_name)
             descriptions.append(nonebot.plugin.get_plugin(plugin_name).metadata.description)
-        return self.plugin_names + self.original_plugin_names, descriptions
+        return self.plugin_names + self.original_plugin_meta_names, descriptions
 
     def get_plugin_menu_data(self, plugin_name: str) -> Union[PluginMenuData, PluginMetadata, str]:
         """
@@ -571,12 +639,13 @@ class DataManager(object):
             else:  # 超限处理
                 return 'PluginIndexOutRange'
         else:  # 模糊匹配
-            result = self.fuzzy_match_and_check(plugin_name, self.plugin_names + self.original_plugin_names)
+            result = self.fuzzy_match_and_check(plugin_name, self.plugin_names + self.original_plugin_meta_names)
             # 空值返回异常字符串
             if result is not None:
                 # 判断插件是否是无menu_data的插件
-                if result in self.original_plugin_names:
-                    return nonebot.plugin.get_plugin(result).metadata
+                if result in self.original_plugin_meta_names:
+                    true_name_index = self.original_plugin_meta_names.index(result)
+                    return nonebot.plugin.get_plugin(self.original_plugin_names[true_name_index]).metadata
                 else:
                     for plugin_data in self.plugin_menu_data_list:
                         if result == plugin_data.name:
